Braintree.ErrorResponse (Braintree v0.14.0)
A general purpose response wrapper that is built for any failed API response.
See the following pages for details about the various processor responses:
Summary
Types
Functions
Link to this function