Braintree.Search (Braintree v0.14.0)
This module performs advanced search on a resource.
For additional reference see: https://developers.braintreepayments.com/reference/general/searching/search-fields/ruby
Summary
Functions
Perform an advanced search on a given resource and create new structs based on the initializer given.
Functions
Link to this function
perform(params, resource, initializer, opts \\ [])
@spec perform(map(), String.t(), (... -> any()), Keyword.t()) :: {:ok, [any()]} | Braintree.HTTP.error()
Perform an advanced search on a given resource and create new structs based on the initializer given.
Example
search_params = %{first_name: %{is: "Jenna"}} {:ok, customers} = Braintree.Search.perform(search_params, "customers", &Braintree.Customer.new/1)