Braintree.SettlementBatchSummary.Record (Braintree v0.14.0)
A record contains details for a transaction in a summary.
Summary
Functions
Convert a list of records into structs, including any custom fields that were used as the grouping value.
Types
Functions
Link to this function
new(params)
Convert a list of records into structs, including any custom fields that were used as the grouping value.