Braintree.Testing.Nonces (Braintree v0.14.0)

A collection of static payment nonces provided to simplify testing server side code.

Nonces are preferred over credit card numbers when testing payment methods. Only a subset of nonces are defined here, for the full list see the sandbox documentation about payment method nonces.

Summary

Functions

Link to this function

abstract_transactable()

Link to this function

android_pay_amex_nonce()

Link to this function

android_pay_discover_nonce()

Link to this function

android_pay_mastercard_nonce()

Link to this function

android_pay_visa_nonce()

Link to this function

apple_pay_am_ex()

Link to this function

apple_pay_master_card()

Link to this function

apple_pay_visa()

Link to this function

paypal_future_payment()

Link to this function

venmo_account()