Braintree.Webhook.Digest (Braintree v0.14.0)
This module provides convenience methods to help validate Braintree signatures and associated payloads for webhooks.
Summary
Functions
Returns the message as a hex-encoded string to validate it matches the signature from the braintree webhook event.
A wrapper function that does a secure comparision accounting for timing attacks.
Functions
Link to this function
hexdigest(private_key, message)
Returns the message as a hex-encoded string to validate it matches the signature from the braintree webhook event.
Link to this function
secure_compare(left, right)
A wrapper function that does a secure comparision accounting for timing attacks.